import { BaseOpenAISDKHandler } from './shared/baseOpenAI';
import { LLMProvider } from '../constants/llmProvider';
/**
 * Contains constants representing various models supported by OpenAI.
 */
export declare abstract class OpenAISupportedModels {
    /** OpenAI GPT-4 model. */
    static readonly GPT_4: string;
    /** OpenAI GPT-4o model. */
    static readonly GPT_4_O: string;
    /** OpenAI GPT-4o Mini model. */
    static readonly GPT_4_O_MINI: string;
}
/**
 * Manages interactions with the OpenAI LLM provider, handling tool calls and model-specific settings.
 */
export declare class OpenAI extends BaseOpenAISDKHandler {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
}
